@@ -1,22 +1,22 @@
 /*  input_plugin.h -  Use this to write input plugins
  *  Copyright (C) 1999-2002 Andy Lo A Foe <andy@alsaplayer.org>
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of AlsaPlayer.
+ *
+ *  AlsaPlayer is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  AlsaPlayer is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
- *
- *  $Id: input_plugin.h,v 1.14 2003/04/08 15:14:57 adnans Exp $
+ *  $Id: input_plugin.h 1250 2007-07-08 14:17:12Z dominique_libre $
  *  
  */ 
 
@@ -50,6 +50,11 @@
  */
 #define P_STREAMBASED	16
 
+/**
+ * Set minimal buffer 
+ */
+#define P_BUFFERING	32
+
 /*
  * Format of version number is 0x1000 + version
  * So 0x1001 is *binary* format version 1
@@ -109,6 +114,10 @@ typedef struct _input_object
 	 * allocated data structure to this pointer
 	 */
 	void *local_data;
+	/** Path of the currently played file
+	 * 
+	 */
+	char* path;
 	/**
 	 * The object mutex. Used to lock and unlock the data structures.
 	 * Initialized and called from the HOST.
