@@ -1,22 +1,22 @@
 /*  CorePlayer.cpp - Core player object, most of the hacking is done here!  
  *	Copyright (C) 1998-2003 Andy Lo A Foe <andy@alsaplayer.org>
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of AlsaPlayer.
+ *
+ *  AlsaPlayer is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  AlsaPlayer is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
- *
- *  $Id: CorePlayer.cpp 1114 2007-05-19 10:22:25Z dominique_libre $
+ *  $Id: CorePlayer.cpp 1267 2007-07-09 20:14:22Z dominique_libre $
  *
 */ 
 
@@ -132,11 +132,15 @@ void CorePlayer::UnRegisterNotifier(coreplayer_notifier *core_notif)
 	UnlockNotifiers();
 }
 
-
+// some arch don't define PATH_MAX
+#ifndef PATH_MAX
+#define PATH_MAX 1024
+#endif
 
 void CorePlayer::load_input_addons()
 {
-	char path[1024];
+        char path[PATH_MAX];
+	
 	DIR *dir;
 	struct stat buf;
 	dirent *entry;
@@ -339,6 +343,64 @@ int CorePlayer::RegisterPlugin(input_plugin *the_plugin)
 	int error_count = 0;
 	input_plugin *tmp;
 
+	if (the_plugin->name == NULL) {
+		alsaplayer_error("No name");
+		error_count++;
+	}
+	if (the_plugin->author == NULL) {
+		alsaplayer_error("No author");
+		error_count++;
+	}	
+	if (the_plugin->init == NULL) {
+		alsaplayer_error("No init function");
+		error_count++;
+	}
+	if (the_plugin->can_handle == NULL) {
+		alsaplayer_error("No can_handle function");
+		error_count++;
+	}
+	if (the_plugin->open == NULL) {
+		alsaplayer_error("No open function");
+		error_count++;
+	}
+	if (the_plugin->close == NULL) {
+		alsaplayer_error("No close function");
+		error_count++;
+	}
+	if (the_plugin->play_frame == NULL) {
+		alsaplayer_error("No play_frame function");
+		error_count++;
+	}	
+	if (the_plugin->frame_seek == NULL) {
+		alsaplayer_error("No frame_seek function");
+		error_count++;
+	}
+
+	if (the_plugin->nr_frames == NULL) {
+		alsaplayer_error("No nr_frames function");
+		error_count++;
+	}
+	if (the_plugin->frame_size == NULL) {
+		alsaplayer_error("No frame_size function");
+		error_count++;
+	}
+	if (the_plugin->channels == NULL) {
+		alsaplayer_error("No channels function");
+		error_count++;
+	}	
+	if (the_plugin->stream_info == NULL) {
+		alsaplayer_error("No stream_info function");
+		error_count++;
+	}
+	if (the_plugin->shutdown == NULL) {
+		alsaplayer_error("No shutdown function");
+		error_count++;
+	}
+	if (error_count) {
+	    	alsaplayer_error("At least %d error(s) were detected", error_count);
+		return 0;
+	}
+	
 	tmp = &plugins[plugin_count];
 	tmp->version = the_plugin->version;
 	if (tmp->version) {
@@ -346,9 +408,12 @@ int CorePlayer::RegisterPlugin(input_plugin *the_plugin)
 			alsaplayer_error("Wrong version number on plugin (v%d, wanted v%d)",
 					version - INPUT_PLUGIN_BASE_VERSION,
 					INPUT_PLUGIN_VERSION - INPUT_PLUGIN_BASE_VERSION);      
-			return 0;
+			// this is a minor error actually 
+			// no need to stop there
+//			return 0;
 		}
 	}
+
 	tmp->name = the_plugin->name;
 	tmp->author = the_plugin->author;
 	tmp->init = the_plugin->init;
@@ -366,73 +431,13 @@ int CorePlayer::RegisterPlugin(input_plugin *the_plugin)
 	tmp->shutdown = the_plugin->shutdown;
 	tmp->nr_tracks = the_plugin->nr_tracks;
 	tmp->track_seek = the_plugin->track_seek;
-	if (tmp->name == NULL) {
-		alsaplayer_error("No name");
-		error_count++;
-	}
-	if (tmp->author == NULL) {
-		alsaplayer_error("No author");
-		error_count++;
-	}	
-	if (tmp->init == NULL) {
-		alsaplayer_error("No init function");
-		error_count++;
-	}
-	if (tmp->can_handle == NULL) {
-		alsaplayer_error("No can_handle function");
-		error_count++;
-	}
-	if (tmp->open == NULL) {
-		alsaplayer_error("No open function");
-		error_count++;
-	}
-	if (tmp->close == NULL) {
-		alsaplayer_error("No close function");
-		error_count++;
-	}
-	if (tmp->play_frame == NULL) {
-		alsaplayer_error("No play_frame function");
-		error_count++;
-	}	
-	if (tmp->frame_seek == NULL) {
-		alsaplayer_error("No frame_seek function");
-		error_count++;
-	}
-
-	if (tmp->nr_frames == NULL) {
-		alsaplayer_error("No nr_frames function");
-		error_count++;
-	}
-	if (tmp->frame_size == NULL) {
-		alsaplayer_error("No frame_size function");
-		error_count++;
-	}
-	if (tmp->channels == NULL) {
-		alsaplayer_error("No channels function");
-		error_count++;
-	}	
-	if (tmp->stream_info == NULL) {
-		alsaplayer_error("No stream_info function");
-		error_count++;
-	}
-	if (tmp->shutdown == NULL) {
-		alsaplayer_error("No shutdown function");
-		error_count++;
-	}
-	if (error_count) {
-	    	alsaplayer_error("At least %d error(s) were detected", error_count);
-		//Unlock();
-		return 0;
-	}
+	
 	if (!tmp->init()) {
-		alsaplayer_error("Plugin failed to initialize (\"%s\")",
-				tmp->name);
+		alsaplayer_error("Plugin failed to initialize (\"%s\")", tmp->name);
 		return 0;
 	}	
 	plugin_count++;
-	if (plugin_count == 1) { // First so assign plugin
-		//plugin = tmp;
-	}
+	
 	if (global_verbose)
 		alsaplayer_error("Loading Input plugin: %s", tmp->name);
 
@@ -590,7 +595,7 @@ bool CorePlayer::Start()
 	last_read = -1;
 	output_rate = node->SamplingRate();
 	input_rate = plugin->sample_rate(the_object);
-	
+
 	if (input_rate == output_rate)
 		SetSpeedMulti(1.0);
 	else
@@ -752,8 +757,9 @@ float CorePlayer::GetSpeed()
 {
 	if (repitched) { // Pitch was changed so return this instead
 		return pitch_point;
-	}	
-	return (read_direction == DIR_FORWARD ? pitch : -pitch);
+	}
+	float ret_pitch = pitch / pitch_multi;
+	return (read_direction == DIR_FORWARD ? ret_pitch : -ret_pitch);
 }
 
 
