@@ -1,27 +1,40 @@
 /*  Main.cpp - main() function and other utils
  *  Copyright (C) 1998-2004 Andy Lo A Foe <andy@alsaplayer.org>
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of AlsaPlayer.
+ *
+ *  AlsaPlayer is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  AlsaPlayer is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
- *
- *  $Id: Main.cpp 1060 2007-02-01 13:52:04Z dominique_libre $
+ *  $Id: Main.cpp 1298 2007-10-08 19:14:29Z dominique_libre $
  *
  *  VIM: set ts=8
  *
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef ENABLE_NLS
+#include <libintl.h>
+#define _(String) gettext(String)
+#define N_(String) noop_gettext(String)
+#else
+#define _(String) (String)
+#define N_(String) String
+#endif
+
 #include <cstdio>
 #include <cstdlib>
 #include <csignal>
@@ -40,8 +53,6 @@
 #include <cstdarg>
 #include <locale.h>
 
-#include "config.h"
-
 #include "AlsaPlayer.h"
 #include "SampleBuffer.h"
 #include "CorePlayer.h"
@@ -267,7 +278,7 @@ static void help()
 		"\n"
 		"  -c,--config file        use given config file for this session\n"
 		"  -h,--help               print this help message\n"
-		"  -i,--interface iface    use specific interface [default=gtk]. choices:\n");
+		"  -i,--interface iface    use specific interface [default=gtk2]. choices:\n");
 	printf(
 		"                          [ ");
 	list_available_plugins("interface");
@@ -443,9 +454,15 @@ int main(int argc, char **argv)
 	signal(SIGILL, exit_sighandler);	// illegal instruction
 	signal(SIGFPE, exit_sighandler);	// floating point exc.
 	signal(SIGABRT, exit_sighandler);	// abort()
+
 	// Enable locale support
+#ifdef ENABLE_NLS
 	setlocale (LC_ALL, "");
-	
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	textdomain(PACKAGE);
+	bind_textdomain_codeset (PACKAGE, "UTF-8");
+#endif
+
 	// Init global mutexes
 	pthread_mutex_init(&playlist_sort_seq_mutex, NULL);
 #if !defined(EMBEDDED)
@@ -863,6 +880,11 @@ int main(int argc, char **argv)
 	// Initialise playlist - must be done before things try to register with it
 	playlist = new Playlist(node);
 
+	if (!prefs_get_bool(ap_prefs, "main", "play_on_start", false))	
+		playlist->Pause();
+	else
+		playlist->UnPause();
+	
 	if (!playlist) {
 		alsaplayer_error("Failed to create Playlist object");
 		return 1;
@@ -883,10 +905,9 @@ int main(int argc, char **argv)
 		playlist->Insert(newitems, playlist->Length());
 	} else {
 		prefsdir = get_prefsdir();
-		snprintf(thefile, sizeof(prefsdir)-28, "%s/alsaplayer.m3u", prefsdir);
+		snprintf(thefile, sizeof(thefile)-28, "%s/alsaplayer.m3u", prefsdir);
 		playlist->Load(thefile, playlist->Length(), false);
 	}
-	playlist->UnPause();
 		
 	// Loop song
 	if (do_loopsong) {
@@ -917,10 +938,13 @@ int main(int argc, char **argv)
 		}
 	} else {
 		char *interface = prefs_get_string
-			(ap_prefs, "main", "default_interface", "gtk");
-		// if we're trying to use the gtk interface, but we have no
+			(ap_prefs, "main", "default_interface", "gtk2");
+		// if we're trying to use the old gtk-1 interface, use gtk-2 instead
+		if (strcmp (interface, "gtk") == 0)
+			interface = "gtk2";
+				// if we're trying to use the gtk interface, but we have no
 		// $DISPLAY, use the text interface instead
-		if (strcmp (interface, "gtk") == 0 && !getenv("DISPLAY"))
+		if (strcmp (interface, "gtk2") == 0 && !getenv("DISPLAY"))
 			interface = "text";
 		if (!(interface_plugin_info = load_interface(interface))) {
 			if (!(interface_plugin_info = load_interface(prefs_get_string
@@ -953,7 +977,7 @@ int main(int argc, char **argv)
 	}
 	// Save playlist before exit
 	prefsdir = get_prefsdir();
-	snprintf(thefile, sizeof(prefsdir)-25, "%s/alsaplayer", prefsdir);
+	snprintf(thefile, sizeof(thefile)-25, "%s/alsaplayer", prefsdir);
 	playlist->Save(thefile, PL_FORMAT_M3U);
 
 	// Save preferences
