@@ -1,26 +1,28 @@
 /*  prefs.c - Preferences system
- *  Copyright (C) 2002 Andy Lo A Foe <andy@alsaplayer.org>
+ *  Copyright (C) 2002-2004 Andy Lo A Foe <andy@alsaplayer.org>
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of AlsaPlayer.
+ *
+ *  AlsaPlayer is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  AlsaPlayer is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  *  Inspired by xine's prefs 
  *
- *  $Id: prefs.c,v 1.14 2003/04/18 23:42:26 adnans Exp $
+ *  $Id: prefs.c 1251 2007-07-08 14:31:34Z dominique_libre $
  *
 */ 
 #include "prefs.h"
+#include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -135,9 +137,11 @@ prefs_handle_t *prefs_load(const char *filename)
 void prefs_set_int(prefs_handle_t *prefs, const char *section, char *key, int val)
 {
 	char str[1024];
+
+	assert(prefs);
+	assert(key);
+	assert(section);
 	
-	if (!prefs || !key || !section)
-		return;
 	sprintf(str, "%d", val);
 	prefs_set_string(prefs, section, key, str);
 }
@@ -147,8 +151,10 @@ void prefs_set_bool(prefs_handle_t *prefs, const char *section, char *key, int v
 {
 	char str[1024];
 
-	if (!prefs || !key || !section)
-		return;
+	assert(prefs);
+	assert(key);
+	assert(section);
+	
 	sprintf(str, "%s", val ? "true" : "false");
 	prefs_set_string(prefs, section, key, str);
 }
@@ -158,8 +164,10 @@ static prefs_key_t *prefs_find_key(prefs_handle_t *prefs, const char *section, c
 {
 	prefs_key_t *entry;
 
-	if (!prefs || !key || !section)
-		return NULL;
+	assert(prefs);
+	assert(key);
+	assert(section);
+	
 	entry = prefs->keys;
 	while (entry) {
 		if (strcmp(entry->section, section)==0 && strcmp(entry->key, key)==0)
@@ -173,8 +181,9 @@ void prefs_set_string(prefs_handle_t *prefs, const char *section, char *key, cha
 {
 	prefs_key_t *entry;
 
-	if (!prefs || !key || !section)
-		return;
+	assert(prefs);
+	assert(key);
+	assert(section);
 
 	if ((entry = prefs_find_key(prefs, section, key))) { /* Already in prefs, replace */
 		free(entry->value);
@@ -222,9 +231,11 @@ void prefs_set_string(prefs_handle_t *prefs, const char *section, char *key, cha
 void prefs_set_float(prefs_handle_t *prefs, const char *section, char *key, float val)
 {
 	char str[1024];
+
+	assert(prefs);
+	assert(key);
+	assert(section);
 	
-	if (!prefs || !key || !section)
-		return;
 	sprintf(str, "%.6f", val);
 	prefs_set_string(prefs, section, key, str);
 }
@@ -234,9 +245,11 @@ int prefs_get_bool(prefs_handle_t *prefs, const char *section, char *key, int de
 {
 	char str[1024];
 	char *res;
+
+	assert(prefs);
+	assert(key);
+	assert(section);
 	
-	if (!prefs || !key || !section)
-		return -1;
 	sprintf(str, "%s", default_val ? "true" : "false");
 	res = prefs_get_string(prefs, section, key, str);
 	if (strncasecmp(res, "true", 4) == 0 ||
@@ -253,9 +266,11 @@ int prefs_get_int(prefs_handle_t *prefs, const char *section, char *key, int def
 	char str[1024];
 	char *res;
 	int val;
+
+	assert(prefs);
+	assert(key);
+	assert(section);
 	
-	if (!prefs || !key)
-		return -1;
 	sprintf(str, "%d", default_val);
 	res = prefs_get_string(prefs, section, key, str);
 	if (sscanf(res, "%d", &val) != 1)
@@ -267,8 +282,9 @@ char *prefs_get_string(prefs_handle_t *prefs, const char *section, char *key, ch
 {
 	prefs_key_t *entry;
 
-	if (!prefs || !key || !section)
-		return default_val;
+	assert(prefs);
+	assert(key);
+	assert(section);
 
 	if ((entry = prefs_find_key(prefs, section, key))) {
 		return entry->value;
@@ -284,9 +300,11 @@ float prefs_get_float(prefs_handle_t *prefs, const char *section, char *key, flo
 	char str[1024];
 	char *res;
 	float val;
+
+	assert(prefs);
+	assert(key);
+	assert(section);
 	
-	if (!prefs || !key)
-		return default_val;
 	sprintf(str, "%.6f", default_val);
 	res = prefs_get_string(prefs, section, key, str);
 	if (sscanf(res, "%f", &val) != 1)
@@ -301,8 +319,10 @@ int prefs_save(prefs_handle_t *prefs)
 	prefs_key_t *entry = NULL;
 	prefs_key_t *sorted = NULL;
 	int c;
-		
-	if (!prefs || !prefs->filename || !strlen(prefs->filename)) {
+	
+	assert(prefs);
+
+	if (!prefs->filename || !strlen(prefs->filename)) {
 		return -1;
 	}
 
@@ -342,8 +362,8 @@ int prefs_save(prefs_handle_t *prefs)
 void prefs_free(prefs_handle_t *prefs)
 {
 	prefs_key_t *entry;
-    
-	if (!prefs)  return;
+   
+	assert(prefs);
 
 	entry = prefs->keys;
 	while (entry) {
