@@ -9,19 +9,20 @@
  *  by Andy Lo A Foe. If you use use this please be so kind as to put a
  *  pointer to the web page at http://www.alsa-project.org/~andy
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
+ *  This file is part of AlsaPlayer.
  *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *  AlsaPlayer is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  AlsaPlayer is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -309,45 +310,58 @@ int create_socket (unchar *unchar_address, int int_port)
 char * send_to_server (int server_fd, char *message)
 {
 	ssize_t	total, i;
-	int 	len = BUFFER_SIZE * 8;
-	char	*response, temp[len];
+	int 	len = BUFFER_SIZE;
+	char	*response, *temp;
+
+	temp = (char *) malloc(BUFFER_SIZE);
 
 	/* write 'message' to the server */
 	if (send (server_fd, message, strlen (message), MSG_DONTWAIT) < 0) 
 	{
 		alsaplayer_error("%s: %s\n", message, strerror (errno));
+		free (temp);
 		return (NULL);
 	}
 
-#ifdef DEBUG
+	if (global_verbose) {
 	/* print the message sent to the server */
 	alsaplayer_error("-> %s", message);
-#endif
+	}
 
 	/* read the response from the server */
 	total = 0;
 	do
 	{
-		i = read (server_fd, temp + total, len - total);
+		i = read (server_fd, temp + total, BUFFER_SIZE);
 		if (i < 0)
 		{
 			alsaplayer_error("%s\n", strerror (errno));
+			free (temp);
 			return (NULL);
 		}
 		total += i;
+		if (total + BUFFER_SIZE > len)
+		{
+			temp = (char *) realloc(temp, len + BUFFER_SIZE);
+			len += BUFFER_SIZE;
+		}
 	}
 	while (total > 2 && temp[total - 2] != '\r' && i != 0);
 
 	if (total < 2)
+	{
+		free (temp);
 		return (NULL);
+	}
 
 	temp[total-2] = '\0';		/* temp[total-1] == \r; temp[total] == \n	*/
 	response = strdup (temp);	/* duplicate the response from the server	*/
+	free(temp);
 
-#ifdef DEBUG
+	if (global_verbose) {
 	/* print the message sent to the server */
 	alsaplayer_error("<- %s", response);
-#endif
+	}
 
 	return (response);
 }
@@ -544,6 +558,32 @@ char * cddb_local_lookup (char *path, unsigned int cd_id)
 	return (NULL);
 }
 
+char*
+cut_html_head(char *answer)
+{
+	if(!answer)
+		return NULL;
+		
+	char *new_answer;
+	int counter = 0, i = 0;
+
+	for (i = 0; i < strlen(answer); i++) {
+		if (*(answer+i) == '\n') {
+			if (counter < 3) {
+				new_answer = strdup(answer+i+1);
+				free(answer);
+				return new_answer;
+			}
+			counter = 0;
+		}
+		
+		counter++;
+	}
+
+	free(answer);
+	return NULL; 
+}
+
 /*
  * search for the song in the CDDB given address/port, returning it's name, or
  * NULL if not found.
@@ -551,11 +591,11 @@ char * cddb_local_lookup (char *path, unsigned int cd_id)
 char * cddb_lookup (char *address, char *char_port, int discID, struct cd_trk_list *tl)
 {
 	int port = atoi (char_port);
-	int server_fd, i, j, n;
+	int server_fd, i, j;
 	int total_secs = 0, counter = 0;
 	char *answer = NULL, *username, *filename, categ[20], newID[9];
 	char msg[BUFFER_SIZE], offsets[BUFFER_SIZE], tmpbuf[BUFFER_SIZE];
-	char hostname[MAXHOSTNAMELEN], server[80];
+	char hostname[MAXHOSTNAMELEN], separator='+';
 
 	/* try to create a socket to the server */
 	if (global_verbose)
@@ -570,37 +610,37 @@ char * cddb_lookup (char *address, char *char_port, int discID, struct cd_trk_li
 			printf ("OK\n");
 
 	/* get the initial message from the server */
-	n = read (server_fd, server, 80);
-	if (n >= 0)
-		server[n] = '\0';
-	if (n >= 2)
-		server[n-2] = '\0';
-
-	if (global_verbose) {
-		printf ("\n<- %s\n", server);
-		printf ("Saying HELLO to CDDB server ...\n");
+	if (port > 80) {
+		answer = send_to_server (server_fd, "");
+		if (global_verbose) {
+			printf ("Saying HELLO to CDDB server ...\n");
+		}
+		free (answer);
 	}
-
 	/* set some settings before saying HELLO to the CDDB server */
 	username = getlogin ();
 	if ((gethostname (hostname, sizeof (hostname))) < 0)
 		snprintf (hostname, sizeof (hostname), "unknown");
 
-	snprintf (msg, sizeof (msg), "cddb hello %s %s %s %s\r\n", username, hostname,PACKAGE, VERSION);
-	answer = send_to_server (server_fd, msg);
-	if (! answer)
-	{
-		alsaplayer_error("bad response from the server\n");
-		close (server_fd);
-		return (NULL);
+	if (port > 80) {
+		snprintf (msg, sizeof (msg), "cddb hello %s %s %s %s\r\n\r\n", username, hostname,PACKAGE, VERSION);
+			
+		answer = send_to_server (server_fd, msg);
+		if (! answer)
+		{
+			alsaplayer_error("bad response from the server\n");
+			close (server_fd);
+			return (NULL);
+		}
+		separator=' ';
 	}
-
 	/* set another settings before querying the CDDB database */
 	tmpbuf[0] = '\0';
 	for (i = 0; i < tl->max; i++) 
 	{
 		/* put the frame offset of the starting location of each track in a string */
-		snprintf (offsets, sizeof (offsets), "%s %d ", tmpbuf, 
+		//snprintf (offsets, sizeof (offsets), "%s %d ", tmpbuf,
+		snprintf (offsets, sizeof (offsets), "%s%c%d", tmpbuf, separator,
 				tl->l_frame[i] + (75 * (tl->l_sec[i] + (60 * tl->l_min[i]))));
 		strcpy (tmpbuf, offsets);
 		counter += tl->l_frame[i] + (75 * tl->l_sec[i] + (60 * tl->l_min[i]));
@@ -609,8 +649,13 @@ char * cddb_lookup (char *address, char *char_port, int discID, struct cd_trk_li
 	total_secs = tl->l_sec[tl->max] + (tl->l_min[tl->max] * 60);
 
 	/* send it */
-	snprintf (msg, sizeof (msg), "cddb query %08x %d %s %d\r\n", discID, tl->max, offsets, total_secs);
-	free(answer);
+	if (port > 80) 
+		snprintf (msg, sizeof (msg), "cddb query %08x %d %s %d\r\n", discID, tl->max, offsets, total_secs);
+	else
+		snprintf (msg, sizeof (msg), "GET /~cddb/cddb.cgi?cmd=cddb+query+%08x+%d%s+%d&hello=%s+%s+%s+%s&proto=6 HTTP/1.0\r\n\r\n", discID, tl->max, offsets, total_secs, username, hostname,PACKAGE, VERSION);
+	
+	if (answer)
+		free(answer);
 	answer = send_to_server (server_fd, msg);
 	if (! answer)
 	{
@@ -624,58 +669,96 @@ char * cddb_lookup (char *address, char *char_port, int discID, struct cd_trk_li
 	 * if answer == "211...", found too many matches
 	 * if answer == "202...", found no matches
 	 */
+	
+	if (port <= 80)  
+		answer = cut_html_head(answer);
+	
+	if (!answer)
+		return NULL;
+			 
 	i = 0;
 	if (! (strncmp (answer, "211", 3)))
 	{
 		/* seek the 2nd line */
-		while (answer[i] != '\n')
+		while (answer[i] != '\n') {
+			if (! answer[i])
+				goto error;
 			++i;
+		}
 
 		/* copy the 1st match to the category */
 		j = 0; 
 		i++;
-		while (j < 19 && answer[i] != ' ') 
+		while (j < 19 && answer[i] != ' ') {
+			if (! answer[i])
+				goto error;
 			categ[j++] = answer[i++];
+		}
 		categ[j++] = '\0';
-		while (answer[i] != ' ') 
+		while (answer[i] != ' ') {
+			if (! answer[i])
+				goto error;
 			i++;
+		}
 
 		/* get the new cdID given from the CDDB */
 		j = 0; 
 		i++;
-		while (j < 8 && answer[i] != ' ') 
+		while (j < 8 && answer[i] != ' ') {
+			if (! answer[i])
+				goto error;
 			newID[j++] = answer[i++];
+		}
 		newID[j++] = '\0';
-		while (answer[i] != ' ') 
+		while (answer[i] != ' ') {
+			if (! answer[i])
+				goto error;
 			i++;
+		}
 
 	} 
 	else if (! (strncmp (answer, "200", 3)))
 	{
 		/* get it from the 1st line */
-		while (answer[i] != ' ')
+		while (answer[i] != ' ') {
+			if (! answer[i])
+				goto error;
 			i++;
+		}
 		i++;
 
 		/* copy the match to the category */
 		j = 0;
-		while (j < 19 && answer[i] != ' ') 
+		while (j < 19 && answer[i] != ' ') {
+			if (! answer[i])
+				goto error;
 			categ[j++] = answer[i++];
+		}
 		categ[j++] = '\0';
-		while (answer[i] != ' ') 
+		while (answer[i] != ' ') {
+			if (! answer[i])
+				goto error;
 			i++;
+		}
 
 		/* copy the new cdID */
 		j = 0; 
 		i++;
-		while (j < 8 && answer[i] != ' ') 
+		while (j < 8 && answer[i] != ' ') {
+			if (! answer[i])
+				goto error;
 			newID[j++] = answer[i++];
+		}
 		newID[j++] = '\0';
-		while (answer[i] != ' ') 
+		while (answer[i] != ' ') {
+			if (! answer[i])
+				goto error;
 			i++;
+		}
 	} 
 	else 
 	{
+	error:
 		alsaplayer_error("Could not find any matches for %08x\n\n", discID);
 		close (server_fd);
 		free(answer);
@@ -684,7 +767,13 @@ char * cddb_lookup (char *address, char *char_port, int discID, struct cd_trk_li
 
 	/* read from the server */
 
-	sprintf (msg, "cddb read %s %s\r\n", categ, newID);
+	if (port > 80)
+		sprintf (msg, "cddb read %s %s\r\n", categ, newID);
+	else {
+		server_fd = create_socket ((unchar *) address, port);
+		snprintf (msg, sizeof (msg), "GET /~cddb/cddb.cgi?cmd=cddb+read+%s+%s&hello=%s+%s+%s+%s&proto=6 HTTP/1.0\r\n\r\n", categ, newID, username, hostname,PACKAGE, VERSION);
+	}
+	
 	free(answer);
 	answer = send_to_server(server_fd, msg);
 
@@ -726,6 +815,7 @@ void cddb_read_file (char *file, struct cdda_local_data *data)
 {
 	char line[BUFFER_SIZE], name[BUFFER_SIZE];
 	char *token = NULL, *tmp, *divider, *s, *post;
+	char album[BUFFER_SIZE];
 	int i, index = 1;
 	FILE *f;
 
@@ -779,6 +869,10 @@ void cddb_read_file (char *file, struct cdda_local_data *data)
 				}
 				continue;
 			} else {
+				// workaround album name on multiple lines, need improvment
+				if (data->tracks[1].album)
+					continue;
+				  
 				/* print the album name */
 				tmp = strtok (line, "=");
 				if (!tmp) { 
@@ -793,12 +887,13 @@ void cddb_read_file (char *file, struct cdda_local_data *data)
 				divider = strstr (tmp, " / ");
 				if (!divider) { 
 					alsaplayer_error("No divider found in DTITLE");
-					data->tracks[1].artist = strdup(tmp);
-					data->tracks[1].album = strdup(tmp);
+					
+					    	data->tracks[1].artist = strdup(tmp);
+						data->tracks[1].album = strdup(tmp);
 				} else {
-					data->tracks[1].album = strdup (divider+3);
-					tmp[strlen(tmp)-strlen(data->tracks[1].album)-3] = '\0';
-					data->tracks[1].artist = strdup (tmp);
+						data->tracks[1].album = strdup (divider+3);
+						tmp[strlen(tmp)-strlen(data->tracks[1].album)-3] = '\0';
+						data->tracks[1].artist = strdup (tmp);
 				}	
 				if ((s = strstr(data->tracks[1].artist, "\r"))) {
 					*s = '\0';
@@ -853,7 +948,7 @@ void cddb_update_info(struct cdda_local_data *data)
 	{
 		/* if could not, try to get it from the internet connection.. */
 		cddb_servername = prefs_get_string(ap_prefs, "cdda", "cddb_servername", "freedb.freedb.org");
-		cddb_serverport = prefs_get_string(ap_prefs, "cdda", "cddb_serverport", "888"); 
+		cddb_serverport = prefs_get_string(ap_prefs, "cdda", "cddb_serverport", "80"); 
 		if (global_verbose)
 			alsaplayer_error("CDDB server: %s:%s", cddb_servername, cddb_serverport);	    
 		file_name = cddb_lookup(cddb_servername, cddb_serverport, cd_id, tl);
@@ -1168,9 +1263,9 @@ static int cdda_stream_info(input_object *obj, stream_info *info)
 		info->title[0] = 0;
 	else if (data->track_nr == 0)
 		sprintf(info->title, "Full CD length playback");
-	else
-		sprintf(info->title, "%s", data->tracks[data->track_nr].track);
-
+	else if (data->tracks[data->track_nr].track)
+			sprintf(info->title, "%s", data->tracks[data->track_nr].track);
+	
 	//alsaplayer_error("title = %s\nalbum = %s\nartist = %s",
 	//		info->title, info->album, info->artist);
 	return 1;
