@@ -3,21 +3,28 @@
 //
 //  Copyright (c) 2002 by Drew Hess <dhess@bothan.net>
 //
-//    This program is free software; you can redistribute it and/or modify
-//    it under the terms of the GNU General Public License as published by
-//    the Free Software Foundation; either version 2 of the License, or
-//    (at your option) any later version.
-//
-//    This program is distributed in the hope that it will be useful,
-//    but WITHOUT ANY WARRANTY; without even the implied warranty of
-//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//    GNU General Public License for more details.
-//
-//    You should have received a copy of the GNU General Public License
-//    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+/*  This file is part of AlsaPlayer.
+ *
+ *  AlsaPlayer is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  AlsaPlayer is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
+ */
 //--------------------------------------------------------------------------
 
+#if !defined(FLAC_API_VERSION_CURRENT) || FLAC_API_VERSION_CURRENT < 8
+#define LEGACY_FLAC
+#else
+#undef LEGACY_FLAC
+#endif
 
 #include <string>
 #include <cstdio>
@@ -319,7 +326,11 @@ input_plugin_info (void)
     memset (&flac_plugin, 0, sizeof(input_plugin));
 
     flac_plugin.version      = INPUT_PLUGIN_VERSION;
-    flac_plugin.name         = "flac player v1.2";
+#ifdef LEGACY_FLAC
+    flac_plugin.name         = "flac player v1.1.2";
+#else
+    flac_plugin.name         = "flac player v1.1.3/1.1.4/1.2";
+#endif
     flac_plugin.author       = "Drew Hess";
     flac_plugin.init         = flac_init;
     flac_plugin.shutdown     = flac_shutdown;
