@@ -2,19 +2,23 @@
  *  daemon.c - Daemon interface
  *  Copyright (C) 2002 Andy Lo A Foe <andy@alsaplayer.org>
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This file is part of AlsaPlayer.
+ *
+ *  AlsaPlayer is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation; either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  AlsaPlayer is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
+ *  $Id: daemon.cpp 1253 2007-07-08 15:57:29Z dominique_libre $
+ *
  */ 
 
 #include <cstdio>
@@ -142,6 +146,7 @@ int daemon_start(Playlist *playlist, int /*argc*/, char ** /*argv*/)
 	}
 	if (ap_get_session_name(global_session_id, session_name)) {
 		fprintf(stdout, "Session \"%s\" is ready.\n", session_name);
+		fflush(stdout);
 	}
 
 	// wait for finish, signalled via pipe
